@@ -8,10 +8,12 @@
 #define EDITORPLUGINMANAGER_H
 
 #include "editorplugininterface.h"
-#include "typenames.h"
 #include "graphtheory_export.h"
-#include <QObject>
+#include "typenames.h"
 #include <QList>
+#include <QObject>
+
+#include <memory>
 
 class KPluginInfo;
 
@@ -37,18 +39,12 @@ public:
      *
      * \return list of plugin interfaces of loaded plugins
      */
-    QList <EditorPluginInterface*> plugins() const;
+    QList<EditorPluginInterface *> plugins() const;
 
 private:
-    /**
-     * \internal
-     * Clears list of plugins and reloads them.
-     */
-    void loadPlugins();
+    static EditorPluginManager *instance;
 
-    static EditorPluginManager * instance;
-
-    const QScopedPointer<EditorPluginManagerPrivate> d;
+    const std::unique_ptr<EditorPluginManagerPrivate> d;
 };
 }
 
