@@ -8,44 +8,36 @@
 #define FILEFORMATMANAGER_H
 
 #include "fileformatinterface.h"
-#include "typenames.h"
+#include "fileformatmanager_p.h"
 #include "graphtheory_export.h"
-#include <QObject>
 #include <QList>
-
-class KPluginInfo;
+#include <QObject>
+#include <memory>
 
 namespace GraphTheory
 {
 
-class FileFormatManagerPrivate;
-
 /** \class FileFormatManager
  * The FileFormatManager provides access to all graph file format plugins. The backend manager loads
  * plugins on creation. For loading, the path "$QT_PLUGIN_PATH/rocs/fileformats" is searched for all plugins.
  */
-class GRAPHTHEORY_EXPORT FileFormatManager : public QObject
+class GRAPHTHEORY_EXPORT FileFormatManager
 {
-    Q_OBJECT
 public:
     /**
      * Selector for graph file backend with specific capability.
      */
-    enum PluginType {
-        Import,
-        Export
-    };
+    enum PluginType { Import, Export };
 
     FileFormatManager();
-
-    ~FileFormatManager() override;
+    ~FileFormatManager() = default;
 
     /**
      * Returns list of loaded backends. Backends are loaded with first call to \see self().
      *
      * \return list of plugin interfaces of loaded backends
      */
-    QList <FileFormatInterface*> backends() const;
+    QList<FileFormatInterface *> backends() const;
 
     /**
      * Returns list of all loaded backends with specified capability (\see PluginType).
@@ -54,7 +46,7 @@ public:
      * \param type specifies capability of the plugin
      * \return list of plugin interfaces of loaded backends
      */
-    QList <FileFormatInterface*> backends(PluginType type) const;
+    QList<FileFormatInterface *> backends(PluginType type) const;
 
     /**
      * Returns an arbitrary loaded plugin that can handle extension \p ext. If no backend specifies
@@ -64,7 +56,7 @@ public:
      * \param ext specifies the extension string
      * \return backend to handle files with specified extension or 0 otherwise
      */
-    FileFormatInterface * backendByExtension(const QString &ext);
+    FileFormatInterface *backendByExtension(const QString &ext) const;
 
     /**
      * Returns the default backend used for serialization/loading of graph files. Use this if
@@ -72,18 +64,10 @@ public:
      *
      * \return plugin interface for the graph file backend
      */
-    FileFormatInterface * defaultBackend();
+    FileFormatInterface *defaultBackend() const;
 
 private:
-    /**
-     * \internal
-     * Clears list of backends and reloads them from dynamic service trader.
-     */
-    void loadBackends();
-
-    static FileFormatManager * instance;
-
-    const QScopedPointer<FileFormatManagerPrivate> d;
+    const std::unique_ptr<FileFormatManagerPrivate> d;
 };
 }
 
