@@ -9,21 +9,13 @@
 #include "gmlgrammar.h"
 #include "gmlgrammarhelper.h"
 #include "logging_p.h"
+#include <QVariant>
 
 #define KGV_MAX_ITEMS_TO_LOAD std::numeric_limits<size_t>::max()
 #define BOOST_SPIRIT_DEBUG 1
 
 using namespace GraphTheory;
 
-// workaround for linking boost
-namespace boost
-{
-void throw_exception(std::exception const &e)
-{
-    qCCritical(GRAPHTHEORY_FILEFORMAT) << "Exception:" << e.what();
-}
-}
-
 namespace GmlParser
 {
 
