@@ -12,9 +12,25 @@
 #include "rocsversion.h"
 #include "settings.h"
 
+#include "grapheditorwidget.h"
 #include "libgraphtheory/kernel/kernel.h"
 #include "libgraphtheory/view.h"
-
+#include "plugins/scriptapi/scriptapiwidget.h"
+#include "project/project.h"
+#include "ui/codeeditorwidget.h"
+#include "ui/documenttypeswidget.h"
+#include "ui/fileformatdialog.h"
+#include "ui/journalwidget.h"
+#include "ui/scriptoutputwidget.h"
+#include "ui/sidedockwidget.h"
+#include <KActionCollection>
+#include <KActionMenu>
+#include <KConfigDialog>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KRecentFilesAction>
+#include <KTar>
+#include <KToolBar>
 #include <QActionGroup>
 #include <QApplication>
 #include <QCloseEvent>
@@ -29,32 +45,14 @@
 #include <QPointer>
 #include <QPushButton>
 #include <QQuickWidget>
+#include <QRegularExpression>
 #include <QSplitter>
 #include <QToolButton>
-
-#include <kwidgetsaddons_version.h>
-#include <KActionCollection>
-#include <KActionMenu>
-#include <KConfigDialog>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <KRecentFilesAction>
-#include <KTar>
-#include <KToolBar>
 #include <ktexteditor/configpage.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/editor.h>
 #include <ktexteditor/view.h>
-
-#include "grapheditorwidget.h"
-#include "plugins/scriptapi/scriptapiwidget.h"
-#include "project/project.h"
-#include "ui/codeeditorwidget.h"
-#include "ui/documenttypeswidget.h"
-#include "ui/fileformatdialog.h"
-#include "ui/journalwidget.h"
-#include "ui/scriptoutputwidget.h"
-#include "ui/sidedockwidget.h"
+#include <kwidgetsaddons_version.h>
 
 using namespace GraphTheory;
 
@@ -173,20 +171,14 @@ QWidget *MainWindow::setupScriptPanel()
     m_stopScript = new QAction(QIcon::fromTheme("process-stop"), i18nc("@action:intoolbar Script Execution", "Stop"), this);
     m_stopScript->setToolTip(i18nc("@info:tooltip", "Stop script execution."));
     m_stopScript->setEnabled(false);
-    m_openDebugger = new QAction(QIcon::fromTheme("system-run"), i18nc("@action:intoolbar Open Debugger", "Debugger"), this);
-    m_openDebugger->setToolTip(i18nc("@info:tooltip", "Open the Javascript code debugger."));
-    m_openDebugger->setCheckable(true);
     executeCommands->addAction(m_runScript);
     executeCommands->addAction(m_stopScript);
-    executeCommands->addAction(m_openDebugger);
     // add actions to action collection to be able to set shortcuts on them in the ui
     actionCollection()->addAction("_runScript", m_runScript);
     actionCollection()->addAction("_stopScript", m_stopScript);
-    actionCollection()->addAction("_openDebugger", m_openDebugger);
 
     connect(m_runScript, &QAction::triggered, this, &MainWindow::executeScript);
     connect(m_stopScript, &QAction::triggered, this, &MainWindow::stopScript);
-    connect(m_openDebugger, &QAction::triggered, this, &MainWindow::checkDebugger);
 
     m_hScriptSplitter->addWidget(m_codeEditorWidget);
     m_hScriptSplitter->addWidget(m_outputWidget);
@@ -330,7 +322,6 @@ void MainWindow::importCodeDocument()
     if (fileUrl.isEmpty()) {
         return;
     }
-
     m_currentProject->importCodeDocument(fileUrl);
     Settings::setLastOpenedDirectory(startDirectory);
 }
@@ -412,11 +403,15 @@ void MainWindow::openProject(const QUrl &fileName)
         return;
     }
     Project *project = new Project(file, m_graphEditor);
-    setProject(project);
-    m_recentProjects->addUrl(file);
-    updateCaption();
+    if (!project->isValid()) {
+        KMessageBox::error(nullptr, i18nc("@info", "The Rocs project could not be imported because the project file could not be parsed."));
+    } else {
+        setProject(project);
+        m_recentProjects->addUrl(file);
+        updateCaption();
 
-    Settings::setLastOpenedDirectory(file.path());
+        Settings::setLastOpenedDirectory(file.path());
+    }
 }
 
 void MainWindow::updateCaption()
@@ -445,9 +440,9 @@ QString MainWindow::uniqueFilename(const QString &basePrefix, const QString &suf
     QString fullPrefix = basePrefix;
 
     if (fullPrefix.isNull()) {
-        fullPrefix = m_currentProject->projectUrl().fileName().remove(QRegExp(".rocs*$"));
+        fullPrefix = m_currentProject->projectUrl().fileName().remove(QRegularExpression(".rocs*$"));
     } else if (fullPrefix.endsWith(fullSuffix)) {
-        fullPrefix.remove(QRegExp(fullSuffix + '$'));
+        fullPrefix.remove(QRegularExpression(fullSuffix + '$'));
     }
 
     targetFile.setFileName(basePath + fullPrefix + fullSuffix);
@@ -495,10 +490,10 @@ bool MainWindow::queryClose()
 #else
     const int btnCode = KMessageBox::warningYesNoCancel(this,
 #endif
-                                                        i18nc("@info", "Changes on your project are unsaved. Do you want to save your changes?"),
-                                                        QString(),
-                                                        KStandardGuiItem::save(),
-                                                        KStandardGuiItem::discard());
+                                                             i18nc("@info", "Changes on your project are unsaved. Do you want to save your changes?"),
+                                                             QString(),
+                                                             KStandardGuiItem::save(),
+                                                             KStandardGuiItem::discard());
 
     if (btnCode == KMessageBox::Cancel) {
         return false;
@@ -559,10 +554,6 @@ void MainWindow::executeScript()
     QString script = m_codeEditorWidget->activeDocument()->text();
     enableStopAction();
 
-    if (m_openDebugger->isChecked()) {
-        m_kernel->triggerInterruptAction();
-    }
-
     m_kernel->execute(m_currentProject->activeGraphDocument(), script);
 }
 
@@ -572,15 +563,6 @@ void MainWindow::stopScript()
     disableStopAction();
 }
 
-void MainWindow::checkDebugger()
-{
-    if (m_openDebugger->isChecked()) {
-        m_kernel->attachDebugger();
-    } else {
-        m_kernel->detachDebugger();
-    }
-}
-
 void MainWindow::enableStopAction()
 {
     m_stopScript->setEnabled(true);
